import { GenericResource } from "@lib/types.ts";
import { Head } from "$fresh/runtime.ts";

function generateJsonLd(resource: GenericResource): string {
  const imageUrl = resource.meta?.image
    ? `/api/images?image=${resource.meta.image}&width=1200`
    : "/images/og-image.jpg";

  const baseSchema: Record<string, unknown> = {
    "@context": "https://schema.org",
    "@type": resource.type.charAt(0).toUpperCase() + resource.type.slice(1), // Converts type to PascalCase
    name: resource.name,
    description: resource.content || resource.meta?.average || "",
    keywords: resource.tags?.join(", ") || "",
    image: imageUrl,
  };

  if (resource.meta?.author) {
    baseSchema.author = {
      "@type": "Person",
      name: resource.meta.author,
    };
  }

  if (resource.meta?.date) {
    try {
      baseSchema.datePublished = new Date(resource.meta.date).toISOString();
    } catch (_) {
      // Ignore invalid date
    }
  }

  if (resource.meta?.rating) {
    baseSchema.aggregateRating = {
      "@type": "AggregateRating",
      ratingValue: resource.meta.rating,
      ratingCount: 1,
      bestRating: 5, // Assuming a scale of 1 to 10
    };
  }

  return JSON.stringify(baseSchema, null, 2);
}

export function MetaTags({ resource }: { resource: GenericResource }) {
  const jsonLd = generateJsonLd(resource);

  const imageUrl = resource.meta?.image
    ? `/api/images?image=${resource.meta.image}&width=1200`
    : "/images/og-image.jpg";
  return (
    <>
      <Head>
        <meta property="og:title" content={resource.name} />
        <meta property="og:type" content={resource.type} />
        <meta
          property="og:image"
          content={imageUrl}
        />
        <script
          type="application/ld+json"
          dangerouslySetInnerHTML={{ __html: jsonLd }}
        />
      </Head>
    </>
  );
}
