import { Handlers } from "$fresh/server.ts";
import { oauth2Client } from "@lib/auth.ts";
import { setCookie } from "@std/http/cookie";

export const codeChallengeMap = new Map<
  string,
  { codeVerifier: string; redirect?: string }
>();

export const handler: Handlers = {
  async GET(req) {
    const url = new URL(req.url);

    const { codeVerifier, uri } = await oauth2Client.code.getAuthorizationUri();

    const codeChallenge = uri.searchParams.get("code_challenge");
    if (!codeChallenge) return new Response();

    codeChallengeMap.set(codeChallenge, {
      codeVerifier,
      redirect: decodeURIComponent(url.searchParams.get("redirect") || ""),
    });

    const headers = new Headers();
    setCookie(headers, {
      name: "code_challenge",
      value: codeChallenge,
    });
    headers.append("location", uri.href);

    return new Response(null, {
      headers,
      status: 302,
    });
  },
};
