import { Handlers, PageProps } from "$fresh/server.ts";
import { MainLayout } from "@components/layouts/main.tsx";
import { Article, getAllArticles } from "@lib/resource/articles.ts";
import { KMenu } from "@islands/KMenu.tsx";
import { Grid } from "@components/Grid.tsx";
import { IconArrowLeft } from "@components/icons.tsx";
import { RedirectSearchHandler } from "@islands/Search.tsx";
import { parseResourceUrl, searchResource } from "@lib/search.ts";
import { GenericResource } from "@lib/types.ts";
import { ResourceCard } from "@components/Card.tsx";
import { Link } from "@islands/Link.tsx";

export const handler: Handlers<
  { articles: Article[] | null; searchResults?: GenericResource[] }
> = {
  async GET(req, ctx) {
    const articles = await getAllArticles();
    const searchParams = parseResourceUrl(req.url);
    const searchResults = searchParams &&
      await searchResource({ ...searchParams, types: ["article"] });
    return ctx.render({ articles, searchResults });
  },
};

export default function Greet(
  props: PageProps<
    { articles: Article[] | null; searchResults: GenericResource[] }
  >,
) {
  const { articles, searchResults } = props.data;
  return (
    <MainLayout
      url={props.url}
      title="Articles"
      context={{ type: "article" }}
      searchResults={searchResults}
    >
      <header class="flex gap-4 items-center mb-5 md:hidden">
        <Link
          class="px-4 ml-4 py-2 bg-gray-300 text-gray-800 rounded-lg flex items-center gap-1"
          href="/"
        >
          <IconArrowLeft class="w-5 h-5" />
          Back
        </Link>

        <h3 class="text-2xl text-white font-light">📝 Articles</h3>
      </header>
      <RedirectSearchHandler />
      <KMenu type="main" context={{ type: "article" }} />
      <Grid>
        {articles?.map((doc) => (
          <ResourceCard
            sublink="articles"
            res={doc}
          />
        ))}
      </Grid>
    </MainLayout>
  );
}
